pub enum DependsOn {
Simple(Vec<String>),
Conditional(IndexMap<String, DependsOnSettings>),
}Expand description
With the depends_on attribute, you can control the order of service startup and shutdown.
It is useful if services are closely coupled, and the startup sequence impacts the application’s functionality.
See more: https://docs.docker.com/reference/compose-file/services/#depends_on
Variants
Implementations