pub enum DeployMode {
Global,
Replicated,
ReplicatedJob,
GlobalJob,
}Expand description
Defines the replication model used to run a service or job. See more: https://docs.docker.com/reference/compose-file/deploy/#mode
Variants
Global
Ensures exactly one task continuously runs per physical node until stopped.
Replicated
Continuously runs a specified number of tasks across nodes until stopped (default).
ReplicatedJob
Executes a defined number of tasks until a completion state (exits with code 0)’. Total tasks are determined by replicas. Concurrency can be limited using the max-concurrent option (CLI only).
GlobalJob
Executes one task per physical node with a completion state (exits with code 0). Automatically runs on new nodes as they are added.