pub enum LoggingDriver {
Local,
JsonFile,
Syslog,
Journald,
Gelf,
Fluentd,
Awslogs,
Splunk,
Etwlogs,
Gcplogs,
}Expand description
A logging driver for Docker.
Variants
Local
Logs are stored in a custom format designed for minimal overhead.
JsonFile
The logs are formatted as JSON. The default logging driver for Docker.
Syslog
Writes logging messages to the syslog facility. The syslog daemon must be running on the host machine.
Journald
Writes log messages to journald. The journald daemon must be running on the host machine.
Gelf
Writes log messages to a Graylog Extended Log Format (GELF) endpoint such as Graylog or Logstash.
Fluentd
Writes log messages to fluentd (forward input). The fluentd daemon must be running on the host machine.
Awslogs
Writes log messages to Amazon CloudWatch Logs.
Splunk
Writes log messages to splunk using the HTTP Event Collector.
Etwlogs
Writes log messages as Event Tracing for Windows (ETW) events. Only available on Windows platforms.
Gcplogs
Writes log messages to Google Cloud Platform (GCP) Logging.