pub enum PullPolicy {
Always,
Build,
Daily,
Missing,
Never,
Refresh,
Weekly,
Other(String),
}Expand description
Defines the decisions Compose makes when it starts to pull images.
See more: https://docs.docker.com/reference/compose-file/services/#pull_policy
Variants
Always
Compose always pulls the image from the registry.
Build
Compose builds the image. Compose rebuilds the image if it’s already present.
Daily
Compose checks the registry for image updates if the last pull took place more than 24 hours ago.
Missing
Compose pulls the image only if it’s not available in the platform cache. This is the default option if you are not also using the Compose Build Specification. if_not_present is considered an alias for this value for backward compatibility. The latest tag is always pulled even when the missing pull policy is used.
Never
Compose doesn’t pull the image from a registry and relies on the platform cached image. If there is no cached image, a failure is reported.
Refresh
Weekly
Compose checks the registry for image updates if the last pull took place more than 7 days ago.
Other(String)