pub struct ComposeFile {
pub name: Option<String>,
pub include: BTreeSet<Include>,
pub services: BTreeMap<String, Service>,
pub configs: BTreeMap<String, TopLevelConfig>,
pub models: BTreeMap<String, TopLevelModel>,
pub networks: BTreeMap<String, TopLevelNetwork>,
pub secrets: BTreeMap<String, TopLevelSecret>,
pub volumes: BTreeMap<String, TopLevelVolume>,
pub extensions: BTreeMap<String, Value>,
}Expand description
Configuration settings for a Docker Compose file.
Fields
name: Option<String>The top-level name property is defined by the Compose Specification as the project name to be used if you don’t set one explicitly.
See more: https://docs.docker.com/reference/compose-file/version-and-name/#name-top-level-element
include: BTreeSet<Include>Requires: Docker Compose 2.20.0 and later
The include top-level section is used to define the dependency on another Compose application, or sub-domain. Each path listed in the include section is loaded as an individual Compose application model, with its own project directory, in order to resolve relative paths.
See more: https://docs.docker.com/reference/compose-file/include/
services: BTreeMap<String, Service>configs: BTreeMap<String, TopLevelConfig>Defines or references configuration data that is granted to services in your Compose application.
See more: https://docs.docker.com/reference/compose-file/configs/
models: BTreeMap<String, TopLevelModel>The top-level models section declares AI models that are used by your Compose application. These models are typically pulled as OCI artifacts, run by a model runner, and exposed as an API that your service containers can consume.
See more: https://docs.docker.com/reference/compose-file/models/
networks: BTreeMap<String, TopLevelNetwork>The named networks for the Compose application.
See more: https://docs.docker.com/reference/compose-file/networks/
secrets: BTreeMap<String, TopLevelSecret>The named secrets for the Compose application.
See more: https://docs.docker.com/reference/compose-file/secrets/
volumes: BTreeMap<String, TopLevelVolume>The named volumes for the Compose application.
See more: https://docs.docker.com/reference/compose-file/volumes/
extensions: BTreeMap<String, Value>Implementations
Sourceimpl ComposeFile
impl ComposeFile