pub struct DependsOnSettings {
pub condition: DependsOnCondition,
pub restart: Option<bool>,
pub required: Option<bool>,
}Expand description
With the depends_on attribute, you can control the order of service startup and shutdow```
It is useful if services are closely coupled, and the startup sequence impacts the application’s functionality.
See more: https://docs.docker.com/reference/compose-file/services/#depends_on
Fields
condition: DependsOnConditionCondition to wait for.
restart: Option<bool>Whether to restart dependent services when this service is restarted.
required: Option<bool>Whether the dependency is required for the dependent service to start. (default: true)