pub struct DevelopmentSettings {
pub watch: Option<BTreeSet<WatchItem>>,
}Expand description
Specifies the development configuration for maintaining a container in sync with source.
See more: https://docs.docker.com/reference/compose-file/develop
Fields
watch: Option<BTreeSet<WatchItem>>The watch attribute defines a list of rules that control automatic service updates based on local file changes. watch is a sequence, each individual item in the sequence defines a rule to be applied by Compose to monitor source code for changes.