pub struct Device {
pub driver: Option<String>,
pub count: Option<StringOrNum>,
pub device_ids: Option<BTreeSet<String>>,
pub capabilities: BTreeSet<String>,
pub options: Option<ListOrMap>,
}Expand description
Device reservations for containers, allowing services to access specific hardware devices.
Fields
driver: Option<String>Device driver to use (e.g., ‘nvidia’).
count: Option<StringOrNum>Number of devices of this type to reserve.
device_ids: Option<BTreeSet<String>>List of specific device IDs to reserve.
capabilities: BTreeSet<String>List of capabilities the device needs to have (e.g., ‘gpu’, ‘compute’, ‘utility’).
options: Option<ListOrMap>Driver-specific options for the device.