pub struct Healthcheck {
pub disable: Option<bool>,
pub test: Option<StringOrList>,
pub interval: Option<String>,
pub start_period: Option<String>,
pub start_interval: Option<String>,
pub retries: Option<StringOrNum>,
pub timeout: Option<String>,
}Expand description
Declares a check that’s run to determine whether or not the service containers are “healthy”.
See more: https://docs.docker.com/reference/compose-file/services/#healthcheck
Fields
disable: Option<bool>Disable any container-specified healthcheck. Set to true to disable.
test: Option<StringOrList>The test to perform to check container health. Can be a string or a list. The first item is either NONE, CMD, or CMD-SHELL. If it’s CMD, the rest of the command is exec’d. If it’s CMD-SHELL, the rest is run in the shell.
interval: Option<String>Time between running the check (e.g., ‘1s’, ‘1m30s’). Default: 30s.
start_period: Option<String>Start period for the container to initialize before starting health-retries countdown (e.g., ‘1s’, ‘1m30s’). Default: 0s.
start_interval: Option<String>Time between running the check during the start period (e.g., ‘1s’, ‘1m30s’). Default: interval value.
retries: Option<StringOrNum>Number of consecutive failures needed to consider the container as unhealthy. Default: 3.
timeout: Option<String>Maximum time to allow one check to run (e.g., ‘1s’, ‘1m30s’). Default: 30s.