pub struct IncludeSettings {
pub path: Option<StringOrSortedList>,
pub project_directory: Option<String>,
pub env_file: Option<StringOrList>,
}Expand description
Compose application or sub-projects to be included.
See more: https://docs.docker.com/reference/compose-file/include/#long-syntax
Fields
path: Option<StringOrSortedList>Defines the location of the Compose file(s) to be parsed and included into the local Compose model.
project_directory: Option<String>Defines a base path to resolve relative paths set in the Compose file. It defaults to the directory of the included Compose file.
env_file: Option<StringOrList>Defines an environment file(s) to use to define default values when interpolating variables in the Compose file being parsed. It defaults to .env file in the project_directory for the Compose file being parsed.
See more: https://docs.docker.com/reference/compose-file/include/#env_file