pub struct Limits {
pub cpus: Option<StringOrNum>,
pub memory: Option<String>,
pub pids: Option<StringOrNum>,
}Expand description
Resource constraints and reservations for the service.
Fields
cpus: Option<StringOrNum>Limit for how much of the available CPU resources, as number of cores, a container can use.
memory: Option<String>Limit on the amount of memory a container can allocate (e.g., ‘1g’, ‘1024m’).
pids: Option<StringOrNum>Maximum number of PIDs available to the container.