pub struct Placement {
pub constraints: Option<BTreeSet<String>>,
pub preferences: Option<BTreeSet<Preferences>>,
}Expand description
Specifies constraints and preferences for the platform to select a physical node to run service containers. See more: https://docs.docker.com/reference/compose-file/deploy/#placement
Fields
constraints: Option<BTreeSet<String>>Defines a required property the platform’s node must fulfill to run the service container.
preferences: Option<BTreeSet<Preferences>>Defines a strategy (currently spread is the only supported strategy) to spread tasks evenly over the values of the datacenter node label.