PortSettings

Struct PortSettings 

pub struct PortSettings {
    pub name: Option<String>,
    pub host_ip: Option<String>,
    pub target: Option<StringOrNum>,
    pub published: Option<StringOrNum>,
    pub mode: Option<PortMode>,
    pub protocol: Option<Protocol>,
    pub app_protocol: Option<String>,
}
Settings for a port mapping.

See more: https://docs.docker.com/reference/compose-file/services/#long-syntax-4

Fields

name: Option<String>

A human-readable name for this port mapping.

host_ip: Option<String>

The host IP to bind to.

target: Option<StringOrNum>

The port inside the container.

published: Option<StringOrNum>

The publicly exposed port.

mode: Option<PortMode>

The port binding mode, either ‘host’ for publishing a host port or ‘ingress’ for load balancing.

protocol: Option<Protocol>

The port protocol (tcp or udp).

app_protocol: Option<String>

The application protocol (TCP/IP level 4 / OSI level 7) this port is used for. This is optional and can be used as a hint for Compose to offer richer behavior for protocols that it understands.