pub struct Provider {
pub type_: String,
pub options: Option<BTreeMap<String, ProviderOptions>>,
}Expand description
Defines a service that Compose won’t manage directly. Compose delegated the service lifecycle to a dedicated or third-party component.
See more: https://docs.docker.com/reference/compose-file/services/#provider
Fields
type_: StringExternal component used by Compose to manage setup and teardown lifecycle of the service.
options: Option<BTreeMap<String, ProviderOptions>>Provider-specific options.