pub struct Resources {
pub limits: Option<Limits>,
pub reservations: Option<Reservations>,
}Expand description
Configures physical resource constraints for container to run on platform.
See more: https://docs.docker.com/reference/compose-file/deploy/#resources
Fields
limits: Option<Limits>The platform must prevent the container from allocating more resources.
reservations: Option<Reservations>The platform must guarantee the container can allocate at least the configured amount.