pub struct RollbackConfig {
pub parallelism: Option<i64>,
pub delay: Option<String>,
pub failure_action: Option<RollbackFailureAction>,
pub monitor: Option<String>,
pub max_failure_ratio: Option<f64>,
pub order: Option<OperationsOrder>,
}Expand description
Configures how the service should be rolled back in case of a failing update.
See more: https://docs.docker.com/reference/compose-file/deploy/#rollback_config
Fields
parallelism: Option<i64>The number of containers to rollback at a time.
delay: Option<String>The time to wait between each container group’s rollback
failure_action: Option<RollbackFailureAction>What to do if a rollback fails. One of continue or pause (default pause)
monitor: Option<String>Duration after each task update to monitor for failure (ns|us|ms|s|m|h) (default 0s).
max_failure_ratio: Option<f64>Failure rate to tolerate during a rollback.
order: Option<OperationsOrder>Order of operations during rollbacks. One of stop-first (old task is stopped before starting new one), or start-first (new task is started first, and the running tasks briefly overlap) (default stop-first).