pub struct ServiceConfigOrSecretSettings {
pub source: String,
pub target: Option<String>,
pub uid: Option<String>,
pub gid: Option<String>,
pub mode: Option<StringOrNum>,
}Expand description
Configuration for service configs or secrets, defining how they are mounted in the container.
Fields
source: StringName of the config or secret as defined in the top-level configs or secrets section.
target: Option<String>Path in the container where the config or secret will be mounted. Defaults to /
uid: Option<String>UID of the file in the container. Default is 0 (root).
gid: Option<String>GID of the file in the container. Default is 0 (root).
mode: Option<StringOrNum>File permission mode inside the container, in octal. Default is 0444 for configs and 0400 for secrets.