pub struct ServiceNetworkSettings {
pub interface_name: Option<String>,
pub aliases: Option<BTreeSet<String>>,
pub ipv4_address: Option<String>,
pub ipv6_address: Option<String>,
pub mac_address: Option<String>,
pub priority: Option<i64>,
pub gw_priority: Option<i64>,
pub link_local_ips: Option<BTreeSet<String>>,
pub driver_opts: Option<BTreeMap<String, SingleValue>>,
}Expand description
The networks attribute defines the networks that service containers are attached to, referencing entries under the networks top-level element.
See more: https://docs.docker.com/reference/compose-file/services/#networks
Fields
interface_name: Option<String>Interface network name used to connect to network
aliases: Option<BTreeSet<String>>Alternative hostnames for this service on the network.
ipv4_address: Option<String>Specify a static IPv4 address for this service on this network.
ipv6_address: Option<String>Specify a static IPv6 address for this service on this network.
mac_address: Option<String>Specify a MAC address for this service on this network.
priority: Option<i64>Specify the priority for the network connection.
gw_priority: Option<i64>Specify the gateway priority for the network connection.
link_local_ips: Option<BTreeSet<String>>List of link-local IPs.
driver_opts: Option<BTreeMap<String, SingleValue>>Driver options for this network.