pub struct ServiceVolumeSettings {
pub type_: VolumeType,
pub read_only: Option<bool>,
pub source: Option<String>,
pub target: String,
pub consistency: Option<String>,
pub bind: Option<Bind>,
pub image: Option<ImageVolumeSettings>,
pub tmpfs: Option<TmpfsSettings>,
pub volume: Option<VolumeSettings>,
}Expand description
Configuration for a service volume.
See more: https://docs.docker.com/reference/compose-file/services/#long-syntax-6
Fields
type_: VolumeTypeThe mount type.
read_only: Option<bool>Flag to set the volume as read-only.
source: Option<String>The source of the mount, a path on the host for a bind mount, a docker image reference for an image mount, or the name of a volume defined in the top-level volumes key. Not applicable for a tmpfs mount.
target: StringThe path in the container where the volume is mounted.
consistency: Option<String>The consistency requirements for the mount. Available values are platform specific.
bind: Option<Bind>Configuration specific to bind mounts.
image: Option<ImageVolumeSettings>Configuration specific to image mounts.
tmpfs: Option<TmpfsSettings>/// Configuration specific to tmpfs mounts.
volume: Option<VolumeSettings>Configuration specific to volume mounts.