TopLevelConfig

Struct TopLevelConfig 

pub struct TopLevelConfig {
    pub name: Option<String>,
    pub external: Option<bool>,
    pub content: Option<String>,
    pub environment: Option<String>,
    pub file: Option<String>,
}
Defines or references configuration data that is granted to services in your Compose application.

See more: https://docs.docker.com/reference/compose-file/configs/

Fields

name: Option<String>

The name of the config object in the container engine to look up. This field can be used to reference configs that contain special characters. The name is used as is and will not be scoped with the project name.

external: Option<bool>

If set to true, external specifies that this config has already been created. Compose does not attempt to create it, and if it does not exist, an error occurs.

content: Option<String>

The content is created with the inlined value. Introduced in Docker Compose version 2.23.1.

environment: Option<String>

The config content is created with the value of an environment variable.

file: Option<String>

The config is created with the contents of the file at the specified path.