TopLevelNetwork

Struct TopLevelNetwork 

pub struct TopLevelNetwork {
    pub external: Option<bool>,
    pub name: Option<String>,
    pub internal: Option<bool>,
    pub driver: Option<String>,
    pub attachable: Option<bool>,
    pub enable_ipv6: Option<bool>,
    pub ipam: Option<Ipam>,
    pub driver_opts: Option<BTreeMap<String, Option<SingleValue>>>,
    pub labels: Option<ListOrMap>,
    /* private fields */
}
Network configuration for the Compose application.

See more: https://docs.docker.com/reference/compose-file/networks/

Fields

external: Option<bool>

If set to true, it specifies that this network’s lifecycle is maintained outside of that of the application. Compose doesn’t attempt to create these networks, and returns an error if one doesn’t exist.

See more: https://docs.docker.com/reference/compose-file/networks/#external

name: Option<String>

Custom name for this network.

See more: https://docs.docker.com/reference/compose-file/networks/#name

internal: Option<bool>

By default, Compose provides external connectivity to networks. internal, when set to true, lets you create an externally isolated network.

driver: Option<String>

Specifies which driver should be used for this network. Compose returns an error if the driver is not available on the platform.

For more information on drivers and available options, see Network drivers.

attachable: Option<bool>

If attachable is set to true, then standalone containers should be able to attach to this network, in addition to services. If a standalone container attaches to the network, it can communicate with services and other standalone containers that are also attached to the network.

enable_ipv6: Option<bool>

Enables IPv6 address assignment.

ipam: Option<Ipam>

Specifies a custom IPAM configuration.

See more: https://docs.docker.com/reference/compose-file/networks/#ipam

driver_opts: Option<BTreeMap<String, Option<SingleValue>>>

A list of options as key-value pairs to pass to the driver. These options are driver-dependent.

Consult the network drivers documentation for more information.

labels: Option<ListOrMap>