pub struct UpdateConfig {
pub parallelism: Option<i64>,
pub delay: Option<String>,
pub failure_action: Option<UpdateFailureAction>,
pub monitor: Option<String>,
pub max_failure_ratio: Option<f64>,
pub order: Option<OperationsOrder>,
}Expand description
Configures how the service should be updated. Useful for configuring rolling updates.
See more: https://docs.docker.com/reference/compose-file/deploy/#update_config
Fields
parallelism: Option<i64>The number of containers to update at a time.
delay: Option<String>The time to wait between updating a group of containers.
failure_action: Option<UpdateFailureAction>What to do if an update fails. One of continue, rollback, or pause (default: pause).
monitor: Option<String>Duration after each task update to monitor for failure (ns|us|ms|s|m|h) (default 0s).
max_failure_ratio: Option<f64>Failure rate to tolerate during an update.
order: Option<OperationsOrder>Order of operations during updates. One of stop-first (old task is stopped before starting new one), or start-first (new task is started first, and the running tasks briefly overlap) (default stop-first).