pub struct VolumeSettings {
pub labels: Option<ListOrMap>,
pub nocopy: Option<bool>,
pub subpath: Option<String>,
}Expand description
Configuration specific to volume mounts.
Fields
labels: Option<ListOrMap>Labels to apply to the volume.
nocopy: Option<bool>Flag to disable copying of data from a container when a volume is created.
subpath: Option<String>Path within the volume to mount instead of the volume root.