WatchItem

Struct WatchItem 

pub struct WatchItem {
    pub action: WatchAction,
    pub exec: Option<ServiceHook>,
    pub ignore: Option<BTreeSet<String>>,
    pub include: Option<BTreeSet<String>>,
    pub path: String,
    pub target: Option<String>,
}
An element of the watch mode configuration.

See more: https://docs.docker.com/reference/compose-file/develop/#watch

Fields

action: WatchAction

Action to take when a change is detected.

See more: https://docs.docker.com/reference/compose-file/develop/#action

exec: Option<ServiceHook>

Requires: Docker Compose 2.32.2 and later

Only relevant when action is set to sync+exec. Like service hooks, exec is used to define the command to be run inside the container once it has started.

See more: https://docs.docker.com/reference/compose-file/develop/#exec

ignore: Option<BTreeSet<String>>

Patterns to exclude from watching.

See more: https://docs.docker.com/reference/compose-file/develop/#ignore

include: Option<BTreeSet<String>>

It is sometimes easier to select files to be watched instead of declaring those that shouldn’t be watched with ignore.

See more: https://docs.docker.com/reference/compose-file/develop/#include

path: String

Defines the path to source code (relative to the project directory) to monitor for changes. Updates to any file inside the path, which doesn’t match any ignore rule, triggers the configured action.

target: Option<String>

Only applies when action is configured for sync. Files within path that have changes are synchronized with the container’s filesystem, so that the latter is always running with up-to-date content.