pub struct Deploy {
pub endpoint_mode: Option<EndpointMode>,
pub mode: Option<DeployMode>,
pub replicas: Option<i64>,
pub labels: Option<ListOrMap>,
pub rollback_config: Option<RollbackConfig>,
pub update_config: Option<UpdateConfig>,
pub resources: Option<Resources>,
pub restart_policy: Option<RestartPolicy>,
pub placement: Option<Placement>,
}Expand description
Compose Deploy Specification https://docs.docker.com/reference/compose-file/deploy
Fields
endpoint_mode: Option<EndpointMode>Specifies a service discovery method for external clients connecting to a service. See more: https://docs.docker.com/reference/compose-file/deploy/#endpoint_mode
mode: Option<DeployMode>Defines the replication model used to run a service or job. See more: https://docs.docker.com/reference/compose-file/deploy/#mode
replicas: Option<i64>If the service is replicated (which is the default), replicas specifies the number of containers that should be running at any given time. See more: https://docs.docker.com/reference/compose-file/deploy/#replicas
labels: Option<ListOrMap>Specifies metadata for the service. These labels are only set on the service and not on any containers for the service. This assumes the platform has some native concept of “service” that can match the Compose application model. See more: https://docs.docker.com/reference/compose-file/deploy/#labels
rollback_config: Option<RollbackConfig>Configures how the service should be rolled back in case of a failing update. See more: https://docs.docker.com/reference/compose-file/deploy/#rollback_config
update_config: Option<UpdateConfig>Configures how the service should be updated. Useful for configuring rolling updates. See more: https://docs.docker.com/reference/compose-file/deploy/#update_config
resources: Option<Resources>Configures physical resource constraints for container to run on platform. See more: https://docs.docker.com/reference/compose-file/deploy/#resources
restart_policy: Option<RestartPolicy>Configures if and how to restart containers when they exit. If restart_policy is not set, Compose considers the restart field set by the service configuration. See more: https://docs.docker.com/reference/compose-file/deploy/#restart_policy
placement: Option<Placement>Specifies constraints and preferences for the platform to select a physical node to run service containers. See more: https://docs.docker.com/reference/compose-file/deploy/#placement